# PyAdio

PyAdio is a Python library for ADio.

## Installation

```bash
pip install git+https://github.com/takumi-nishimura/PyAdio.git
```

## Usage
Please refer to the [tests/pyadio_adc.py](tests/pyadio_adc.py)  
```bash
python tests/pyadio_adc.py
```
> [!Tip]
> You can use [pgliveApp](https://github.com/takumi-nishimura/pgliveApp.git) to visualize the ADC waveform.
> ```bash
> pgliveapp --num 6 --col 2
> ```

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENCE.txt) file for details.

* **pydantic** is licensed under the MIT License. [LICENCE](https://github.com/pydantic/pydantic/blob/main/LICENSE)
* **pyserial** is licensed under the BSD 3-Clause License. [LICENCE](https://github.com/pyserial/pyserial/blob/master/LICENSE.txt)
